@@ -4,6 +4,12 @@ as a live Python object.
 
 In MMIF, views are created by apps in a pipeline that are annotating
 data that was previously present in the MMIF file.
+
+The :class:`View` class is a high-level container that provides convenient
+string-based access to annotations via ``view[id]``. The underlying
+``annotations`` attribute is a list-like collection that uses integer indexing;
+use container-level access for ID-based lookups.
+
 """
 import json
 import warnings
@@ -26,9 +32,35 @@ class View(MmifObject):
     a list of annotations, and potentially a JSON-LD ``@context``
     IRI.
 
+    This is a high-level container object that provides convenient string-based
+    access to annotations using their IDs. The underlying ``annotations`` collection
+    is list-like and uses integer indexing, but View itself accepts string IDs for
+    convenient access.
+
     If ``view_obj`` is not provided, an empty View will be generated.
 
     :param view_obj: the JSON data that defines the view
+
+    Examples
+    --------
+    Accessing annotations by ID (high-level, convenient):
+
+    .. code-block:: python
+
+       view = mmif['v1']
+       ann = view['v1:a1']        # Get annotation by ID
+       doc = view['v1:td1']       # Get document by ID
+
+       # Safe access with default:
+       ann = view.get('v1:a999', default=None)
+
+    Accessing via underlying list (positional access):
+
+    .. code-block:: python
+
+       first_ann = view.annotations[0]      # First annotation
+       last_ann = view.annotations[-1]      # Last annotation
+       some_anns = view.annotations[1:5]    # Slice of annotations
     """
 
     def __init__(self, view_obj: Optional[Union[bytes, str, dict]] = None, parent_mmif=None, *_) -> None:
@@ -215,7 +247,7 @@ class View(MmifObject):
         :param document: the Document object to add
         :param overwrite: if set to True, will overwrite
                           an existing view with the same ID
-        :return: None
+        :return: the added Document object (as an Annotation)
         """
         return self.add_annotation(document, overwrite)
 
@@ -270,39 +302,78 @@ class View(MmifObject):
     def get_document_by_id(self, doc_id) -> Document:
         """
         .. deprecated:: 1.1.0
-           Will be removed in 2.0.0. 
-           Use general ``Mmif.__getitem__()`` method instead to retrieve 
-           any document across the MMIF, or View.__getitems__() to 
+           Will be removed in 2.0.0.
+           Use general ``Mmif.__getitem__()`` method instead to retrieve
+           any document across the MMIF, or View.__getitems__() to
            retrieve documents within the view.
 
-        Thinly wraps the Mmif.__getitem__ method and returns an Annotation 
-        object. Note that although this method is under View class, it can 
-        be used to retrieve any annotation across the entire MMIF.
+        Thinly wraps the Mmif.__getitem__ method and returns a Document
+        object. Note that although this method is under View class, it can
+        be used to retrieve any document across the entire MMIF.
 
-        :param ann_id: the ID of the annotation to retrieve.
-        :return: found :class:`mmif.serialize.annotation.Annotation` object.
-        :raises KeyError: if the annotation with the given ID is not found
+        :param doc_id: the ID of the document to retrieve.
+        :return: found :class:`mmif.serialize.annotation.Document` object.
+        :raises KeyError: if the document with the given ID is not found
         """
         warnings.warn(
             "View.get_document_by_id() is deprecated, use view[doc_id] instead.",
             DeprecationWarning
         )
-        doc_found = self.annotations[doc_id]
+        doc_found = self.annotations._items.get(doc_id)
         if not isinstance(doc_found, Document):
             raise KeyError(f"Document \"{doc_id}\" not found in view {self.id}.")
         return cast(Document, doc_found)
 
     def __getitem__(self, key: str) -> 'Annotation':
         """
-        index ([]) implementation for View.
+        High-level string-based access to annotations by their IDs.
 
-        :raises KeyError: if the key is not found
-        :param key: the search string.
-        :return: the :class:`mmif.serialize.annotation.Annotation` object searched for
+        This method provides convenient access to annotations and documents
+        within this view using their string identifiers.
+
+        Note: This is a high-level convenience method on the View container
+        itself. The underlying ``annotations`` collection is list-like and
+        only supports integer indexing.
+
+        :param key: The annotation or document ID (e.g., 'v1:a1', 'v1:td1'),
+                    or an attribute name (e.g., 'metadata', 'annotations')
+        :return: The requested Annotation, Document, or attribute object
+        :raises KeyError: If the key is not found
+
+        Examples
+        --------
+        High-level access by ID:
+
+        .. code-block:: python
+
+           view = mmif['v1']
+
+           # Access annotations:
+           ann = view['v1:a1']     # Returns Annotation with ID 'v1:a1'
+
+           # Access text documents in view:
+           doc = view['v1:td1']    # Returns Document with ID 'v1:td1'
+
+           # Access attributes:
+           metadata = view['metadata']  # Returns ViewMetadata object
+
+           # Will raise KeyError:
+           ann = view['nonexistent']  # KeyError!
+
+        For list-style positional access, use the underlying collection:
+
+        .. code-block:: python
+
+           first_ann = view.annotations[0]              # Integer index
+
+        See Also
+        --------
+        get : Safe access with default value instead of raising KeyError
+        get_annotations : Search for annotations by type or properties
         """
         if key in self._named_attributes():
             return self.__dict__[key]
-        anno_result = self.annotations.get(key)
+        anno_result = self.annotations._items.get(key)
         if not anno_result:
             raise KeyError("Annotation ID not found: %s" % key)
         return anno_result
@@ -346,6 +417,7 @@ class ViewMetadata(MmifObject):
         self.error: Union[dict, ErrorDict] = {}
         self.warnings: List[str] = []
         self._required_attributes = ["app"]
+        self._contextual_attributes = {"timestamp"}
         self._attribute_classes = {
             'error': ErrorDict,
             'contains': ContainsDict
@@ -357,8 +429,8 @@ class ViewMetadata(MmifObject):
         # also see this class' `_serialize()` override implementation
         super().__init__(viewmetadata_obj)
 
-    def _serialize(self, alt_container: Optional[Dict] = None) -> dict:
-        serialized = super()._serialize()
+    def _serialize(self, *args, **kwargs) -> dict:
+        serialized = super()._serialize(**kwargs)
         # `_serialize()` eliminates any *empty* attributes, so 
         # when no "contains", "errors", nor "warnings", at least add an empty contains back
         if not (self.contains.items() or self.error or self.warnings):
@@ -459,6 +531,7 @@ class ErrorDict(MmifObject):
     def __init__(self, error_obj: Optional[Union[bytes, str, dict]] = None, *_) -> None:
         self.message: str = ''
         self.stackTrace: str = ''
+        self._contextual_attributes = {"stackTrace"}
         super().__init__(error_obj)
     
     def __str__(self):
